# `Ramses`
[![Build Status](https://travis-ci.org/brandicted/ramses.svg?branch=master)](https://travis-ci.org/brandicted/ramses)
[![Documentation](https://readthedocs.org/projects/ramses/badge/?version=stable)](http://ramses.readthedocs.org)

Generate a RESTful API for Pyramid using [RAML](http://raml.org). It uses [Nefertari](https://github.com/brandicted/nefertari) which provides ElasticSearch-powered views.

Looking to get started quickly? You can take a look at the ["Getting Started" guide](https://ramses.readthedocs.org/en/stable/getting_started.html).
